@@ -42,6 +42,4 @@ def basic(request=None):
         'DOMAIN': current_site.domain,
         'SITE_URL': 'http://www.%s' % current_site.domain,
         'SITE_NAME': current_site.name,
-        'SITE_KEYWORDS': settings.SITE_KEYWORDS,
-        'SITE_DESCRIPTION': settings.SITE_DESCRIPTION,
     }
